@@ -27,7 +27,7 @@ import time
 import copy
 from itertools import compress
 
-import graph_metric
+from . import graph_metric
 import sys
 sys.setrecursionlimit(10000)
 
